# CONVERSOR MOEDA REAL

Description. 
The package CONVERSOR_MOEDA_REAL is used to:
	- Convert Float value in monetary Brazilian number

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install CONVERSOR_MOEDA_REAL

```bash
pip install CONVERSOR_MOEDA_REAL
```

## Usage

```python
from moeda import convert as teste
teste.converte()
```

## Author
Evaldo Junior

## License
[MIT](https://choosealicense.com/licenses/mit/)